@@ -23,14 +23,13 @@
 #ifndef _E_CAL_BACKEND_FILE_FACTORY_H_
 #define _E_CAL_BACKEND_FILE_FACTORY_H_
 
-#include <glib-object.h>
 #include "libedata-cal/e-cal-backend-factory.h"
 
 G_BEGIN_DECLS
 
 void                 eds_module_initialize (GTypeModule *module);
 void                 eds_module_shutdown   (void);
-void                 eds_module_list_types (const GType **types, int *num_types);
+void                 eds_module_list_types (const GType **types, gint *num_types);
 
 G_END_DECLS
 
