@@ -30,6 +30,10 @@
 #include <unistd.h>
 #include <glib/gi18n.h>
 
+#ifdef ENABLE_MAINTAINER_MODE
+#include <gtk/gtk.h>
+#endif
+
 #ifdef G_OS_UNIX
 #if GLIB_CHECK_VERSION(2,29,5)
 #include <glib-unix.h>
@@ -268,7 +272,8 @@ remove_dead_calendar_cb (gpointer path,
 }
 
 static void
-calendar_freed_cb (EDataCalFactory *factory, GObject *dead)
+calendar_freed_cb (EDataCalFactory *factory,
+                   GObject *dead)
 {
 	EDataCalFactoryPrivate *priv = factory->priv;
 	GHashTableIter iter;
@@ -306,7 +311,8 @@ calendar_freed_cb (EDataCalFactory *factory, GObject *dead)
 }
 
 static void
-last_client_gone_cb (ECalBackend *backend, EDataCalFactory *factory)
+last_client_gone_cb (ECalBackend *backend,
+                     EDataCalFactory *factory)
 {
 	EDataCalFactoryPrivate *priv = factory->priv;
 
@@ -325,7 +331,9 @@ struct find_backend_data {
 };
 
 static void
-find_backend_cb (gpointer key, gpointer value, gpointer data)
+find_backend_cb (gpointer key,
+                 gpointer value,
+                 gpointer data)
 {
 	struct find_backend_data *fbd = data;
 
@@ -535,9 +543,9 @@ impl_CalFactory_get_cal (EGdbusCalFactory *object,
 
 cleanup:
 	/* The reason why the lock is held for such a long time is that there is
-	   a subtle race where e_cal_backend_add_client () can be called just
-	   before e_cal_backend_finalize () is called from the
-	   backend_last_client_gone_cb (), for details see bug 506457. */
+	 * a subtle race where e_cal_backend_add_client () can be called just
+	 * before e_cal_backend_finalize () is called from the
+	 * backend_last_client_gone_cb (), for details see bug 506457. */
 	g_mutex_unlock (priv->backends_mutex);
 
 cleanup2:
@@ -573,7 +581,9 @@ remove_data_cal_cb (gpointer data_cl,
 }
 
 static void
-unref_backend_cb (gpointer key, gpointer value, gpointer user_data)
+unref_backend_cb (gpointer key,
+                  gpointer value,
+                  gpointer user_data)
 {
 	ECalBackend *backend = value;
 
@@ -701,6 +711,8 @@ e_data_cal_factory_register_gdbus_object (EDataCalFactory *factory,
  * @is_online: Online mode to set.
  *
  * Sets the online mode for all backends created by the given factory.
+ *
+ * Since: 3.2
  */
 void
 e_data_cal_factory_set_backend_online (EDataCalFactory *factory,
@@ -850,7 +862,9 @@ e_data_cal_factory_get_n_backends (EDataCalFactory *factory)
 
 /* Frees a uri/backend pair from the backends hash table */
 static void
-dump_backend (gpointer key, gpointer value, gpointer data)
+dump_backend (gpointer key,
+              gpointer value,
+              gpointer data)
 {
 	gchar *uri;
 	ECalBackend *backend;
@@ -957,6 +971,8 @@ on_name_lost (GDBusConnection *connection,
 		g_list_foreach (copy, remove_data_cal_cb, NULL);
 		g_list_free (copy);
 	}
+	g_print ("Superseded...\n");
+	g_main_loop_quit (loop);
 }
 
 #ifdef G_OS_UNIX
@@ -983,7 +999,8 @@ static GOptionEntry entries[] = {
 };
 
 gint
-main (gint argc, gchar **argv)
+main (gint argc,
+      gchar **argv)
 {
 	EOfflineListener *eol;
 	GOptionContext *context;
@@ -1008,7 +1025,7 @@ main (gint argc, gchar **argv)
 
 		p_SetProcessDEPPolicy = GetProcAddress (GetModuleHandle ("kernel32.dll"), "SetProcessDEPPolicy");
 		if (p_SetProcessDEPPolicy)
-			(*p_SetProcessDEPPolicy) (PROCESS_DEP_ENABLE|PROCESS_DEP_DISABLE_ATL_THUNK_EMULATION);
+			(*p_SetProcessDEPPolicy) (PROCESS_DEP_ENABLE | PROCESS_DEP_DISABLE_ATL_THUNK_EMULATION);
 	}
 #endif
 #endif
@@ -1021,6 +1038,11 @@ main (gint argc, gchar **argv)
 	g_set_prgname (E_PRGNAME);
 	if (!g_thread_supported ()) g_thread_init (NULL);
 
+	#ifdef ENABLE_MAINTAINER_MODE
+	/* only to load gtk-modules, like bug-buddy's gnomesegvhandler, if possible */
+	gtk_init_check (&argc, &argv);
+	#endif
+
 	context = g_option_context_new (NULL);
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_parse (context, &argc, &argv, &error);
@@ -1048,7 +1070,7 @@ main (gint argc, gchar **argv)
 	owner_id = g_bus_own_name (
 		G_BUS_TYPE_SESSION,
 		CALENDAR_DBUS_SERVICE_NAME,
-		G_BUS_NAME_OWNER_FLAGS_NONE,
+		G_BUS_NAME_OWNER_FLAGS_REPLACE | G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT,
 		on_bus_acquired,
 		on_name_acquired,
 		on_name_lost,
@@ -1059,7 +1081,11 @@ main (gint argc, gchar **argv)
 	e_data_cal_migrate_basedir ();
 
 #ifdef G_OS_UNIX
-#if GLIB_CHECK_VERSION(2,29,5)
+#if GLIB_CHECK_VERSION(2,29,19)
+	g_unix_signal_add_full (
+		G_PRIORITY_DEFAULT, SIGTERM,
+		handle_term_signal, NULL, NULL);
+#elif GLIB_CHECK_VERSION(2,29,5)
 	g_unix_signal_add_watch_full (
 		SIGTERM, G_PRIORITY_DEFAULT,
 		handle_term_signal, NULL, NULL);
