@@ -82,7 +82,7 @@ extern gss_OID gss_nt_service_name;
 #define DBUS_INTERFACE		"org.gnome.KrbAuthDialog"
 #define DBUS_METHOD		"org.gnome.KrbAuthDialog.acquireTgt"
 
-CamelServiceAuthType camel_sasl_gssapi_authtype = {
+static CamelServiceAuthType sasl_gssapi_auth_type = {
 	N_("GSSAPI"),
 
 	N_("This option will connect to the server using "
@@ -228,7 +228,15 @@ send_dbus_message (gchar *name)
 	/* Sends the message: Have a 300 sec wait timeout  */
 	reply = g_dbus_connection_send_message_with_reply_sync (connection, message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, 300 * 1000, NULL, NULL, &error);
 
+	if (!error && reply) {
+		if (g_dbus_message_to_gerror (reply, &error)) {
+			g_object_unref (reply);
+			reply = NULL;
+		}
+	}
+
 	if (error) {
+		g_dbus_error_strip_remote_error (error);
 		g_warning ("%s: %s\n", G_STRFUNC, error->message);
 		g_error_free (error);
 	}
@@ -236,7 +244,8 @@ send_dbus_message (gchar *name)
 	if (reply) {
 		GVariant *body = g_dbus_message_get_body (reply);
 
-		success = body && g_variant_get_boolean (body);
+		if (body)
+			g_variant_get (body, "(b)", &success);
 
 		g_object_unref (reply);
 	}
@@ -440,6 +449,7 @@ camel_sasl_gssapi_class_init (CamelSaslGssapiClass *class)
 	object_class->finalize = sasl_gssapi_finalize;
 
 	sasl_class = CAMEL_SASL_CLASS (class);
+	sasl_class->auth_type = &sasl_gssapi_auth_type;
 	sasl_class->challenge_sync = sasl_gssapi_challenge_sync;
 #endif /* HAVE_KRB5 */
 }
