@@ -32,10 +32,6 @@
 #include "camel-mime-message.h"
 #include "camel-transport.h"
 
-#define CAMEL_TRANSPORT_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_TRANSPORT, CamelTransportPrivate))
-
 typedef struct _AsyncContext AsyncContext;
 
 struct _CamelTransportPrivate {
@@ -71,7 +67,7 @@ transport_finalize (GObject *object)
 {
 	CamelTransportPrivate *priv;
 
-	priv = CAMEL_TRANSPORT_GET_PRIVATE (object);
+	priv = CAMEL_TRANSPORT (object)->priv;
 
 	g_mutex_free (priv->send_lock);
 
@@ -164,7 +160,8 @@ camel_transport_class_init (CamelTransportClass *class)
 static void
 camel_transport_init (CamelTransport *transport)
 {
-	transport->priv = CAMEL_TRANSPORT_GET_PRIVATE (transport);
+	transport->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		transport, CAMEL_TYPE_TRANSPORT, CamelTransportPrivate);
 
 	transport->priv->send_lock = g_mutex_new ();
 }
@@ -174,7 +171,7 @@ camel_transport_init (CamelTransport *transport)
  * @transport: a #CamelTransport
  * @lock: lock type to lock
  *
- * Locks #transport's #lock. Unlock it with camel_transport_unlock().
+ * Locks %transport's %lock. Unlock it with camel_transport_unlock().
  *
  * Since: 2.32
  **/
@@ -198,7 +195,7 @@ camel_transport_lock (CamelTransport *transport,
  * @transport: a #CamelTransport
  * @lock: lock type to unlock
  *
- * Unlocks #transport's #lock, previously locked with camel_transport_lock().
+ * Unlocks %transport's %lock, previously locked with camel_transport_lock().
  *
  * Since: 2.32
  **/
@@ -232,7 +229,7 @@ camel_transport_unlock (CamelTransport *transport,
  *
  * Returns: %TRUE on success or %FALSE on error
  *
- * Since: 2.92
+ * Since: 3.0
  **/
 gboolean
 camel_transport_send_to_sync (CamelTransport *transport,
@@ -288,7 +285,7 @@ camel_transport_send_to_sync (CamelTransport *transport,
  * When the operation is finished, @callback will be called.  You can then
  * call camel_transport_send_to_finish() to get the result of the operation.
  *
- * Since: 2.92
+ * Since: 3.0
  **/
 void
 camel_transport_send_to (CamelTransport *transport,
@@ -325,7 +322,7 @@ camel_transport_send_to (CamelTransport *transport,
  *
  * Returns: %TRUE on success, %FALSE on error
  *
- * Since: 2.92
+ * Since: 3.0
  **/
 gboolean
 camel_transport_send_to_finish (CamelTransport *transport,
